@@ -3,7 +3,6 @@ from ansible.module_utils.hashivault import hashivault_argspec
 from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
-import requests
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
@@ -65,20 +64,19 @@ EXAMPLES = '''
         oidc_client_id: "123456"
         oidc_client_secret: "123456"
         default_role: "gmail"
-        verify: False
 '''
 
 
 def main():
     argspec = hashivault_argspec()
+    argspec['mount_point'] = dict(required=False, type='str', default='oidc')
     argspec['bound_issuer'] = dict(required=False, type='str', default='')
     argspec['jwks_ca_pem'] = dict(required=False, type='str', default='')
     argspec['jwks_url'] = dict(required=False, type='str')
     argspec['jwt_supported_algs'] = dict(required=False, type='list', default=[])
     argspec['jwt_validation_pubkeys'] = dict(required=False, type='list', default=[])
-    argspec['oidc_discovery_ca_pem'] = dict(required=False, type='str', default='')
-    argspec['mount_point'] = dict(required=False, type='str', default='oidc')
     argspec['oidc_discovery_url'] = dict(required=False, type='str')
+    argspec['oidc_discovery_ca_pem'] = dict(required=False, type='str', default='')
     argspec['oidc_client_id'] = dict(required=False, type='str')
     argspec['oidc_client_secret'] = dict(required=False, type='str')
     argspec['default_role'] = dict(required=False, type='str')
@@ -94,63 +92,38 @@ def main():
 @hashiwrapper
 def hashivault_oidc_auth_method_config(module):
     params = module.params
-    client = hashivault_auth_client(params)
-    changed = False
     mount_point = params.get('mount_point').strip('/')
+    client = hashivault_auth_client(params)
+    parameters = [
+        'bound_issuer',
+        'jwks_ca_pem',
+        'jwks_url',
+        'jwt_supported_algs',
+        'jwt_validation_pubkeys',
+        'oidc_discovery_ca_pem',
+        'oidc_discovery_url',
+        'oidc_client_id',
+        'oidc_client_secret',
+        'default_role',
+    ]
     desired_state = dict()
-    current_state = dict()
-    exists = False
+    for parameter in parameters:
+        if params.get(parameter) is not None:
+            desired_state[parameter] = params.get(parameter)
 
-    token = params.get('token', client.token)
-    namespace = params['namespace']
-    headers = {'X-Vault-Token': token, 'X-Vault-Namespace': namespace}
-    url = params['url']
-    verify = params['verify']
-
-    if not params.get('oidc_discovery_url'):
-        desired_state['oidc_discovery_url'] = ''
-    else:
-        desired_state['oidc_discovery_url'] = params.get('oidc_discovery_url')
-    desired_state['oidc_client_id'] = params.get('oidc_client_id')
-    desired_state['default_role'] = params.get('default_role')
-    desired_state['bound_issuer'] = params.get('bound_issuer')
-    desired_state['jwks_ca_pem'] = params.get('jwks_ca_pem')
-    if not params.get('jwks_url'):
-        desired_state['jwks_url'] = ''
-    else:
-        desired_state['jwks_url'] = params.get('jwks_url')
-    desired_state['jwt_supported_algs'] = params.get('jwt_supported_algs')
-    desired_state['jwt_validation_pubkeys'] = params.get('jwt_validation_pubkeys')
-    desired_state['oidc_discovery_ca_pem'] = params.get('oidc_discovery_ca_pem')
-
-    # check if any config exists
+    changed = False
+    current_state = {}
     try:
-        current_state = requests.get(url + '/v1/auth/' + mount_point + '/config', verify=verify, headers=headers)
-        if current_state.status_code == 404:
-            changed = True
-        elif current_state.status_code == 200:
-            exists = True
+        current_state = getattr(client.auth, mount_point).read_config()['data']
     except Exception:
         changed = True
+    for key in desired_state.keys():
+        if current_state.get(key, None) != desired_state[key]:
+            changed = True
 
-    # check if current config matches desired config values, if they dont match, set changed true
-    if exists:
-        current_state = current_state.json()['data']
-        for k, v in current_state.items():
-            if k in desired_state and v != desired_state[k]:
-                changed = True
-
-    desired_state['oidc_client_secret'] = params.get('oidc_client_secret')
-
-    # if configs dont match and checkmode is off, complete the change
     if changed and not module.check_mode:
-        config_status = requests.post(url + '/v1/auth/' + mount_point + '/config', verify=verify, headers=headers,
-                                      json=desired_state)
-        try:
-            config_status.raise_for_status()
-        except Exception:
-            return {'failed': True, 'msg': config_status.text, 'rc': 1}
-    return {'changed': changed}
+        getattr(client.auth, 'oidc').configure(**desired_state)
+    return {'changed': changed, 'old_state': current_state, 'new_state': desired_state}
 
 
 if __name__ == '__main__':
